pub struct ConfidenceThresholder {
pub threshold: f64,
}Expand description
Threshold a confidence map to produce a binary mask.
Fields
threshold: f64Threshold value in [0, 1]
Implementations
Sourceimpl ConfidenceThresholder
impl ConfidenceThresholder
Sourcepub fn apply(&self, map: &ConfidenceMap) -> Vec<bool>
pub fn apply(&self, map: &ConfidenceMap) -> Vec<bool>
Apply the threshold and return a binary mask (true = accepted).
Sourcepub fn count_accepted(&self, map: &ConfidenceMap) -> usize
pub fn count_accepted(&self, map: &ConfidenceMap) -> usize
Count the number of accepted pixels.
Sourcepub fn acceptance_ratio(&self, map: &ConfidenceMap) -> f64
pub fn acceptance_ratio(&self, map: &ConfidenceMap) -> f64
Return the acceptance ratio [0, 1].