pub struct MotionCompensator { /* private fields */ }Expand description
Motion compensator that estimates and applies motion compensation.
Implementations
Sourceimpl MotionCompensator
impl MotionCompensator
Sourcepub fn new(config: MotionEstimationConfig) -> Self
pub fn new(config: MotionEstimationConfig) -> Self
Create a new motion compensator with the given configuration.
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create with default configuration.
Sourcepub fn estimate(
&self,
reference: &[u8],
target: &[u8],
) -> AlignResult<MotionField>
pub fn estimate( &self, reference: &[u8], target: &[u8], ) -> AlignResult<MotionField>
Estimate motion field between a reference frame and a target frame.
Both frames are provided as grayscale pixel data (one byte per pixel, row-major).
Sourcepub fn compute_stats(field: &MotionField) -> MotionStats
pub fn compute_stats(field: &MotionField) -> MotionStats
Compute motion statistics from a motion field.
Sourcepub fn compensate_points(
field: &MotionField,
points: &[Point2D],
) -> Vec<Point2D>
pub fn compensate_points( field: &MotionField, points: &[Point2D], ) -> Vec<Point2D>
Apply motion compensation to warp a set of points.
Sourcepub fn config(&self) -> &MotionEstimationConfig
pub fn config(&self) -> &MotionEstimationConfig
Get the current configuration.