pub struct MotionField {
pub vectors: Vec<MotionVector>,
pub cols: u32,
pub rows: u32,
pub block_size: u32,
}Expand description
A field of motion vectors covering an entire frame.
Fields
vectors: Vec<MotionVector>Motion vectors in row-major order.
cols: u32Number of blocks horizontally.
rows: u32Number of blocks vertically.
block_size: u32Block size used for estimation.
Implementations
Sourceimpl MotionField
impl MotionField
Sourcepub fn new(frame_width: u32, frame_height: u32, block_size: u32) -> Self
pub fn new(frame_width: u32, frame_height: u32, block_size: u32) -> Self
Create a new motion field with zero vectors.
Sourcepub fn get(&self, bx: u32, by: u32) -> Option<&MotionVector>
pub fn get(&self, bx: u32, by: u32) -> Option<&MotionVector>
Get the motion vector at block position (bx, by).
Sourcepub fn set(&mut self, bx: u32, by: u32, mv: MotionVector)
pub fn set(&mut self, bx: u32, by: u32, mv: MotionVector)
Set the motion vector at block position (bx, by).
Sourcepub fn interpolate(&self, x: f64, y: f64) -> MotionVector
pub fn interpolate(&self, x: f64, y: f64) -> MotionVector
Interpolate a motion vector at a continuous pixel position.
Sourcepub fn global_motion(&self) -> MotionVector
pub fn global_motion(&self) -> MotionVector
Compute global motion from the motion field (median of all vectors).
Sourcepub fn average_magnitude(&self) -> f64
pub fn average_magnitude(&self) -> f64
Compute the average magnitude of all motion vectors.
Sourcepub fn count_above_threshold(&self, threshold: f64) -> usize
pub fn count_above_threshold(&self, threshold: f64) -> usize
Count the number of vectors exceeding a magnitude threshold.