pub struct StreamGroup {
pub name: String,
pub stream_ids: Vec<StreamId>,
/* private fields */
}Expand description
Group of streams to be aligned together
Fields
name: StringName of this group
stream_ids: Vec<StreamId>Stream IDs in this group
Implementations
Sourceimpl StreamGroup
impl StreamGroup
Sourcepub fn add_stream(&mut self, id: StreamId)
pub fn add_stream(&mut self, id: StreamId)
Add a stream to the group
Sourcepub fn add_offset(&mut self, offset: StreamOffset)
pub fn add_offset(&mut self, offset: StreamOffset)
Add a measured offset between two streams
Sourcepub fn select_reference(
&mut self,
strategy: ReferenceStrategy,
) -> Option<StreamId>
pub fn select_reference( &mut self, strategy: ReferenceStrategy, ) -> Option<StreamId>
Select reference stream using the given strategy
Sourcepub fn reference_id(&self) -> Option<StreamId>
pub fn reference_id(&self) -> Option<StreamId>
Get the current reference stream
Sourcepub fn compute_bulk_offsets(&self) -> HashMap<StreamId, StreamOffset>
pub fn compute_bulk_offsets(&self) -> HashMap<StreamId, StreamOffset>
Compute bulk offsets for all streams relative to a given reference
Sourcepub fn compute_bulk_offsets_for_reference(
&self,
ref_id: StreamId,
) -> HashMap<StreamId, StreamOffset>
pub fn compute_bulk_offsets_for_reference( &self, ref_id: StreamId, ) -> HashMap<StreamId, StreamOffset>
Compute bulk offsets for all streams relative to a specific reference
Sourcepub fn offsets(&self) -> &[StreamOffset]
pub fn offsets(&self) -> &[StreamOffset]
Get all offsets in the group