Module multitrack_align

Module multitrack_align 

Multi-track alignment for synchronizing multiple audio/video tracks.

This module provides tools for aligning multiple tracks to a common reference, using cross-correlation of feature vectors to find the best time offset.

Structs

AlignmentAnchor
Anchor point tying a frame to a feature vector for alignment purposes.
AlignmentMatrix
Pairwise frame-offset matrix between a set of tracks.
MultitrackAligner
Aligns multiple tracks to a designated reference track using feature cross-correlation.
TrackAlignment
Result of aligning one track to a reference track.

Enums

AlignMethod
Method used to align two tracks.

Functions

cross_correlate
Compute the normalised cross-correlation of two equal-length (or different- length) sequences.