pub struct MultitrackAligner { /* private fields */ }Expand description
Aligns multiple tracks to a designated reference track using feature cross-correlation.
Implementations
Sourceimpl MultitrackAligner
impl MultitrackAligner
Sourcepub fn set_reference(&mut self, track_id: &str)
pub fn set_reference(&mut self, track_id: &str)
Set the reference track ID.
Sourcepub fn align_track(
&self,
track_id: &str,
anchors: &[AlignmentAnchor],
) -> TrackAlignment
pub fn align_track( &self, track_id: &str, anchors: &[AlignmentAnchor], ) -> TrackAlignment
Align track_id to the reference using the supplied anchors.
For each anchor belonging to track_id, the method searches for the
anchor from the reference track with the matching frame index (or the
closest one) and accumulates cross-correlation evidence. The offset
with the highest aggregate correlation peak is returned.
Panics
Panics if no reference track has been set via Self::set_reference.