pub struct KltTracker {
pub config: KltConfig,
}Expand description
Pyramidal KLT tracker.
Fields
config: KltConfigTracker configuration.
Implementations
Sourceimpl KltTracker
impl KltTracker
Sourcepub fn track_features(
&self,
prev_frame: &[u8],
curr_frame: &[u8],
width: u32,
height: u32,
points: &[(f32, f32)],
) -> AlignResult<Vec<Option<(f32, f32)>>>
pub fn track_features( &self, prev_frame: &[u8], curr_frame: &[u8], width: u32, height: u32, points: &[(f32, f32)], ) -> AlignResult<Vec<Option<(f32, f32)>>>
Track sparse feature points from prev_frame to curr_frame using
pyramidal Lucas-Kanade optical flow.
This is the primary high-level API for KLT tracking. It accepts f32
pixel coordinates (common in feature-detection pipelines) and returns
Some((x, y)) for successfully tracked points or None when tracking
failed (low texture, out-of-bounds, etc.).
Both frames must be single-channel (grayscale), row-major byte images
of size width * height.
Errors
Returns an error if image dimensions are inconsistent or the frame is smaller than 8×8 pixels.
Sourcepub fn track(
&self,
prev_image: &[u8],
curr_image: &[u8],
width: usize,
height: usize,
points: &[Point2D],
) -> AlignResult<Vec<TrackResult>>
pub fn track( &self, prev_image: &[u8], curr_image: &[u8], width: usize, height: usize, points: &[Point2D], ) -> AlignResult<Vec<TrackResult>>
Track a set of points from prev_image to curr_image.
Both images must be single-channel (grayscale), row-major, with the
same width and height.
Errors
Returns an error if the image dimensions are inconsistent.