Multi-track alignment for synchronizing multiple audio/video tracks.
This module provides tools for aligning multiple tracks to a common reference, using cross-correlation of feature vectors to find the best time offset.
Structs
- Alignment
Anchor - Anchor point tying a frame to a feature vector for alignment purposes.
- Alignment
Matrix - Pairwise frame-offset matrix between a set of tracks.
- Multitrack
Aligner - Aligns multiple tracks to a designated reference track using feature cross-correlation.
- Track
Alignment - Result of aligning one track to a reference track.
Enums
- Align
Method - Method used to align two tracks.
Functions
- cross_
correlate - Compute the normalised cross-correlation of two equal-length (or different- length) sequences.